PRTE\_INFO(1) PMIx Reference Run Time Environment PRTE\_INFO(1)

prte\_info — Display information about the PRRTE installation

# [SYNOPSIS](#SYNOPSIS)

**prte\_info \[options]**

# [DESCRIPTION](#DESCRIPTION)

**prte\_info** provides detailed information about the PRRTE installation. It can be useful for at least three common scenarios:

1\.

Checking local configuration and seeing how PRRTE was installed.

2\.

Submitting bug reports / help requests to the PRRTE community (see Getting help &lt;&gt;).

3\.

Seeing a list of installed PRRTE plugins and querying what MCA parameters they support.

# [OPTIONS](#OPTIONS)

**prte\_info** accepts the following options:

- **-h** | **--help &lt;arg0&gt;**: Show help message. If the optional argument is not provided, then a generalized help message similar to the information provided here is returned. If an argument is provided, then a more detailed help message for that specific command line option is returned.
- **-v** | **--verbose**: Enable debug output.
- **-V** | **--version**: Print version and exit.
- **-a** | **--all**: Show all configuration options and MCA parameters.
- **--arch**: Show architecture on which PRRTE was compiled.
- **-c** | **--config**: Show configuration options
- **--hostname**: Show the hostname on which PRRTE was configured and built.
- **--internal**: Show internal MCA parameters (not meant to be modified by users).
- **--param &lt;arg0&gt;:&lt;arg1&gt;,&lt;arg2&gt;**: Show MCA parameters. The first parameter is the framework (or the keyword “all”); the second parameter is a comma-delimited list of specific component names (if only &lt;arg0&gt; is given, then all components will be reported).
- **--path &lt;type&gt;**: Show paths that PRRTE was configured with. Accepts the following parameters: **all**, **prefix**, **bindir**, **libdir**, **incdir**, **pkglibdir**, **sysconfdir**.
- **--pretty-print**: When used in conjunction with other parameters, the output is displayed in “prettyprint” format (default)
- **--parsable**: When used in conjunction with other parameters, the output is displayed in a machine-parsable format
- **--parseable**: Synonym for **--parsable**
- **--color &lt;hue&gt;**: Control color coding: auto (default), never, always
- **--show-failed**: Show the components that failed to load along with the reason why they failed
- **--selected-only**: Show only variables from selected components.

# [EXIT STATUS](#EXIT_STATUS)

Returns 0 if successful, non-zero if an error is encountered

# [EXAMPLES](#EXAMPLES)

Examples of using this command.

Show the default output of options and listing of installed components in a human-readable / prettyprint format:

```
prte_info
```

Show the default output of options and listing of installed components in a machine-parsable format:

```
prte_info --parsable
```

Show the MCA parameters of the “lsf” RMAPS component in a human-readable / prettyprint format:

```
prte_info --param rmaps lsf
```

Show the “bindir” that PRRTE was configured with:

```
prte_info --path bindir
```

Show the version of PRRTE version numbers in a prettyprint format:

```
prte_info --version
```

Show *all* information about the PRRTE installation, including all components that can be found, all the MCA parameters that they support, versions of PRRTE and the components, etc.:

```
prte_info --all
```

**See also:**

[prte(1)](/man/os/prrte/prte.1) &lt;#man1-prte&gt;

# [Copyright](#Copyright)

2003-2026, The PRRTE Community

September 16, 2026

---

Document: prte_info(1) from prrte 4.1.0-r6 (Chainguard OS)
Source: https://github.com/openpmix/prrte
